@@ -124,7 +124,7 @@ void __stdcall Event_CallBackFunction(unsigned char* Data_Content, size_t Data_S
 
     //--------------------------------------------------------------------------
     CLI::CLI() : watch_folder_user(NULL), use_as_user(-1), use_daemon(false), asynchronous(false),
-                 force_analyze(false), full_report(false), include_hidden_files(false), mil_analyze(true),
+                 force_analyze(false), no_database(false), full_report(false), include_hidden_files(false), mil_analyze(true),
                  watch_folder_recursive(true), create_policy_mode(false), file_information(false),
                  plugins_list_mode(false), list_watch_folders_mode(false), no_needs_files_mode(false),
                  list_mode(false), fixer(false)
@@ -146,6 +146,9 @@ void __stdcall Event_CallBackFunction(unsigned char* Data_Content, size_t Data_S
             return CLI_RETURN_ERROR;
         }
 
+        if (no_database)
+            MCL.set_no_database(no_database);
+
         if (!no_needs_files_mode)
         {
             // If no filenames (and no options)
@@ -1045,6 +1048,12 @@ void __stdcall Event_CallBackFunction(unsigned char* Data_Content, size_t Data_S
         force_analyze = force;
     }
 
+    //--------------------------------------------------------------------------
+    void CLI::set_no_database(bool no_db)
+    {
+        no_database = no_db;
+    }
+
     //--------------------------------------------------------------------------
     void CLI::set_mil_analyze(bool analyze)
     {
